/* proxy.h
 *
 * $Id: proxy.h,v 1.2 2000/01/12 22:40:12 nisse Exp $ */

/* lsh, an implementation of the ssh protocol
 *
 * Copyright (C) 1999 Balzs Scheidler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LSH_PROXY_H_INCLUDED
#define LSH_PROXY_H_INCLUDED

#include "alist.h"
#include "command.h"

extern struct collect_info_1 chain_connections;

struct command *
make_proxy_connection_service(struct alist *server_requests,
			      struct alist *client_requests);

struct command *
make_proxy_offer_service(struct alist *services);


#endif /* LSH_PROXY_H_INCLUDED */
